==> 0.2.8.tar.gz: android/src/main/java/com/miaozhen/mzanalytics_mybmw/EventUtils.java <==
package com.miaozhen.mzanalytics_mybmw;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.util.Log;

import com.miaozhen.sitesdk.api.MzSiteSDK;
import com.miaozhen.sitesdk.conf.MzConfig;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class EventUtils {
    /**
     * demo埋点包含:初始化， 页面，基础事件，高级事件，心跳和deeplink功能。
     */

    static MzSiteSDK mzSiteSDK;

    public static void initEvent(Context context) {
        try {
            //SDK 配置相关
            MzConfig config = new MzConfig();
            //调试时设置log开关
            config.setDebugMode(true);
            //SDK初始化
            mzSiteSDK = MzSiteSDK.getInstance(context, config, null);
        } catch (Throwable e) {
            e.printStackTrace();
        }

    }


    public static void trackPageView(Context context, JSONObject pageObject) {
        if (mzSiteSDK == null) {
            initEvent(context);
        }
        try {

            String title = pageObject.optString("dt");
            JSONObject object = pageObject.optJSONObject("CustomDimMetrics");
            mzSiteSDK.trackPageView(title, object);

        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void trackEvent(Context context, JSONObject object) {
        if (mzSiteSDK == null) {
            initEvent(context);
        }
        //基础事件
        try {
            String eventClassifyStr = object.optString("ec");
            String eventActionStr = object.optString("ea");
            String eventTagStr = object.optString("el");
            String eventPriceStr = object.optString("ev");
            JSONObject eventObject = object.optJSONObject("CustomDimMetrics");
            mzSiteSDK.trackEvent(eventClassifyStr, eventActionStr, eventTagStr, eventPriceStr, eventObject);
        } catch (Throwable e) {
            e.printStackTrace();
        }


    }

    public static void trackSiteCustomEvent(Context context, JSONObject object) {
        if (mzSiteSDK == null) {
            initEvent(context);
        }

        //自定义事件和高级事件监测
        try {
            JSONObject customEvent = object.optJSONObject("CustomEvent");
            JSONObject customDimMetrics = object.optJSONObject("CustomDimMetrics");
            mzSiteSDK.trackSiteCustomEvent(customEvent, customDimMetrics);
        } catch (Throwable e) {
            e.printStackTrace();
        }

    }

    public static void trackPulse(Context context) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.trackPulse();
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void deepLinkEvent(Context context, JSONObject object) {
        try {
            Intent intent = new Intent();
            String deeplinkStr = object.optString("linUrl");
            if (deeplinkStr == null || deeplinkStr.equals("")){
                Log.d("mzsdk", "handleOpenURL deeplink参数为空");
                return;
            }
            Uri uriData = Uri.parse(deeplinkStr);
            intent.setData(uriData);

            MzConfig config = new MzConfig();
            //调试时设置log开关
            config.setDebugMode(true);
            mzSiteSDK = MzSiteSDK.getInstance(context, config, intent);
        } catch (Throwable e) {
            e.printStackTrace();
        }

    }

    public static String getCid(Context context) {
        String result = "";
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            result = mzSiteSDK.getCid();
        } catch (Throwable e) {
            e.printStackTrace();
        }
        return result;
    }

    public static String getOaid(Context context) {
        String result = "";
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            result = mzSiteSDK.getOaid();
        } catch (Throwable e) {
            e.printStackTrace();
        }
        return result;
    }


    public static void setCd(Context context, String key, String value) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.setCd(key, value);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void setCm(Context context, String key, String value) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.setCm(key, value);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void deleteCd(Context context, String key) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.deleteCd(key);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void deleteCm(Context context, String key) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.deleteCm(key);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static Map<String, String> getCdAndCm(Context context) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            return mzSiteSDK.getCdAndCm();
        } catch (Throwable e) {
            e.printStackTrace();
            return new HashMap<>();
        }
    }

    public static boolean isAutoTrackpage(Context context) {
        boolean result = false;
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            result = mzSiteSDK.isAutoTrackpage();
        } catch (Throwable e) {
            e.printStackTrace();

        }
        return result;
    }

    public static List<String> getBlackList(Context context) {
        List result = new ArrayList();
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            List tmpList = mzSiteSDK.getBlackList();
            result.addAll(tmpList);
        } catch (Throwable e) {
            e.printStackTrace();

        }
        return result;
    }

}

==> 0.3.5.tar.gz: android/src/main/java/com/miaozhen/mzanalytics_mybmw/EventUtils.java <==
package com.miaozhen.mzanalytics_mybmw;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.util.Log;

import com.miaozhen.sitesdk.api.MzSiteSDK;
import com.miaozhen.sitesdk.conf.HttpConfig;
import com.miaozhen.sitesdk.conf.MzConfig;
import com.miaozhen.sitesdk.util.LOG;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class EventUtils {
    /**
     * 事件包括：初始化、页面、基础、高级事件、心跳、deeplink。
     */

    static MzSiteSDK mzSiteSDK;

    public static void initEvent(Context context) {
        try {
            //SDK 配置相关
            MzConfig config = new MzConfig();
            config.setDebugMode(false);
            mzSiteSDK = MzSiteSDK.getInstance(context, config, null);
        } catch (Throwable e) {
            e.printStackTrace();
        }

    }


    public static void trackPageView(Context context, JSONObject pageObject) {
        if (mzSiteSDK == null) {
            initEvent(context);
        }
        try {

            String title = pageObject.optString("dt");
            JSONObject object = pageObject.optJSONObject("CustomDimMetrics");
            mzSiteSDK.trackPageView(title, object);

        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void trackEvent(Context context, JSONObject object) {
        if (mzSiteSDK == null) {
            initEvent(context);
        }
        //基础事件
        try {
            String eventClassifyStr = object.optString("ec");
            String eventActionStr = object.optString("ea");
            String eventTagStr = object.optString("el");
            String eventPriceStr = object.optString("ev");
            JSONObject eventObject = object.optJSONObject("CustomDimMetrics");
            mzSiteSDK.trackEvent(eventClassifyStr, eventActionStr, eventTagStr, eventPriceStr, eventObject);
        } catch (Throwable e) {
            e.printStackTrace();
        }


    }

    public static void trackSiteCustomEvent(Context context, JSONObject object) {
        if (mzSiteSDK == null) {
            initEvent(context);
        }

        //自定义事件和高级事件监测
        try {
            JSONObject customEvent = object.optJSONObject("CustomEvent");
            JSONObject customDimMetrics = object.optJSONObject("CustomDimMetrics");
            mzSiteSDK.trackSiteCustomEvent(customEvent, customDimMetrics);
        } catch (Throwable e) {
            e.printStackTrace();
        }

    }

    public static void trackPulse(Context context) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.trackPulse();
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void deepLinkEvent(Context context, JSONObject object) {
        try {
            Intent intent = new Intent();
            String deeplinkStr = object.optString("linUrl");
            if (deeplinkStr == null || deeplinkStr.equals("")){
                Log.d("mzsdk", "handleOpenURL deeplink参数为空");
                return;
            }
            Uri uriData = Uri.parse(deeplinkStr);
            intent.setData(uriData);

            MzConfig config = new MzConfig();
            //调试时设置log开关
            config.setDebugMode(false);
            mzSiteSDK = MzSiteSDK.getInstance(context, config, intent);
        } catch (Throwable e) {
            e.printStackTrace();
        }

    }

    public static String getCid(Context context) {
        String result = "";
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            result = mzSiteSDK.getCid();
        } catch (Throwable e) {
            e.printStackTrace();
        }
        return result;
    }

    public static String getOaid(Context context) {
        String result = "";
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            result = mzSiteSDK.getOaid();
        } catch (Throwable e) {
            e.printStackTrace();
        }
        return result;
    }


    public static void setCd(Context context, String key, String value) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.setCd(key, value);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void setCm(Context context, String key, String value) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.setCm(key, value);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void deleteCd(Context context, String key) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.deleteCd(key);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void deleteCm(Context context, String key) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.deleteCm(key);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static Map<String, String> getCdAndCm(Context context) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            return mzSiteSDK.getCdAndCm();
        } catch (Throwable e) {
            e.printStackTrace();
            return new HashMap<>();
        }
    }

    public static boolean isAutoTrackpage(Context context) {
        boolean result = false;
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            result = mzSiteSDK.isAutoTrackpage();
        } catch (Throwable e) {
            e.printStackTrace();

        }
        return result;
    }

    public static List<String> getManualtrackpage(Context context) {
        List result = new ArrayList();
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            List tmpList = mzSiteSDK.getBlackList();
            result.addAll(tmpList);
        } catch (Throwable e) {
            e.printStackTrace();

        }
        return result;
    }

    public static void setLogEnabled(Context context,boolean isDebug) {
        try {
            if (mzSiteSDK == null) {
                initEvent(context);
            }
            mzSiteSDK.setLogEnabled(isDebug);
        } catch (Throwable e) {
            e.printStackTrace();

        }
    }

}
